{% from "utils.html.j2" import page_anchor %}

{% macro last_posts(language, number) %}
  <ul>
    {% set pages = get_storage().get_posts(language=language) %}

    {% for page in pages[:number] %}
      <li>{{page_anchor(page)}}</li>
    {% endfor %}
  </ul>
{% endmacro %}
